@@ -7,7 +7,7 @@ PREVIOUS_TOKEN_MARKERS = (token.INDENT, token.ENDMARKER, token.NEWLINE)
 def _is_docstring(
     tokeninfo: tokenize.TokenInfo, previous_token: tokenize.TokenInfo
 ) -> bool:
-    """Check if a token represents a docstring"""
+    """Check if a token represents a docstring."""
     if (
         tokeninfo.type == token.STRING
         and (
